Contributors
============

Contributors, please add you name here! By doing this, you also state, that you
have signed the Plone Contributors Agreement [1][2]. Thanks!

- Andreas Jung, zopyx
- Franklin Kingma, kingel
- Georg Bernhard, gogo
- Giacomo Spettoli, giacomos
- JeanMichel FRANCOIS, toutpt
- Jens Klein, jensens
- Johannes Raggam, thet (PLIP implementation)
- Lennart Regebro, regebro
- Philip Bauer, pbauer
- Robert Niederreiter, rnixx
- Rok Garbas, garbas
- Róman Joost, romanofski
- Sean Upton, seanupton
- Simone Orsi, simahawk
- Thomas Desvenain, tdesvenain
- Tom Gross, tomgross
- Vincent Fretin, vincentfretin
- Vitaliy Podoba, piv, vipod


Find out who contributed:
$ git shortlog -s -e

[1] http://plone.org/foundation/contributors-agreement/contributors-agreement-explained
[2] http://plone.org/foundation/contributors-agreement/agreement.pdf/view
